# /usr/bin/env python
import os
from cryptography.fernet import Fernet


def decryptFs(filename,hash, key):
    dataList = []
    for chunkName in hash:
        f = open(str(chunkName), 'rb')
        data = f.read()
        encrypted = Fernet(key).decrypt(data)
        dataList.append(encrypted) 
        f.close()
        os.remove(chunkName)
    f2 = open(("f-"+filename), 'wb')
    for data in dataList:
        f2.write(data)
    f2.close()

    









# /usr/bin/env python
import sys, os
from cryptography.fernet import Fernet


def created_folder():
    dirName = "./KeyHash/"
    if not os.path.exists(dirName):
        os.makedirs(dirName)
        print("Directory " , dirName ,  " Created ")


def encryptFs(filename):
    key = Fernet.generate_key()
    fer = Fernet(key)
    created_folder()
    with open(os.path.join("./KeyHash/",("key-"+filename+".pem")), 'wb') as f:
        f.write(key)
    f = open(filename, 'rb')
    data = f.read()
    f.close()

    bytes = len(data)
    if (bytes < 650):
        bytes = 650
    elif(bytes>=1000 & bytes< 1400):
        bytes = 1400
    x = int(bytes * 0.034)

    if sys.version_info.major == 3:
        noOfChunks = int(bytes / x)
    elif sys.version_info.major == 2:
        noOfChunks = bytes / x
    if(bytes % x):
        noOfChunks += 1

    j = 0
    for i in range(0, bytes + 1, x):
        j += 1
        fn1 = "-%s" % (j)
        encrypted_file = fer.encrypt(data[i:i + x])
        fen = filename + fn1
        f = open(fen, 'wb')
        f.write(encrypted_file)
        f.close()





# /usr/bin/env python
import sys, os, argparse
from .encrypt import encryptFs
from .decrypt import decryptFs
from .ipfsApi import ipfsFileget,ipfsFileAdd
import inspect


parser = argparse.ArgumentParser(add_help=False, description='pifs mini command line tools')
parser.add_argument("-ef", "--encyptfile", default="Empty", type = str, dest="ecfile", help=argparse.SUPPRESS)
parser.add_argument("-df", "--decyptfile", default="Empty", type = str, dest="defile", help=argparse.SUPPRESS)

parser.add_argument('-h', '--help', action='store_true')
args = parser.parse_args()
       

def ipfsUpload(filename):
    try:
        hash = []
        encryptFs(filename)
        for i in range(1,31):
            fn1 = filename + "-%s" % (i)
            ipfsFileAdd(fn1)
            h = ipfsFileAdd(fn1)
            hash.append(h)
            os.remove(fn1)
        with open(os.path.join("./KeyHash/",(filename + '-hash.txt')), 'w') as f:
            for item in hash:
                f.write("%s\n" % item)
        print("Upload successes")
    except:
        for i in range(1,31):
            fn1 = filename + "-%s" % (i)
            os.remove(fn1)
        print("Fail to Upload")
        print("make sure you have run > ipfs daemon")

def ipfsDownload(filename):
    try:  
        fn1 = filename + "-hash.txt"
        key1 = "key-" + filename + ".pem"
        hash = [line.rstrip('\n') for line in open(os.path.join('./KeyHash/',fn1))]
        f = open(os.path.join('./KeyHash/',key1))
        key = f.read()
        for i in hash:
            ipfsFileget(i)
        decryptFs(filename,hash, key)
        print("Download successes")
    except:
        print("Download fail")
        print("make sure you have run > ipfs daemon")

ecfile = args.ecfile
defile = args.defile

if args.help:
    print("""
        pifs mini command line tools

        -h or --help bring help message to about pifs 
    
        -e, --encrypt   upload and encrypting files
        -f, --file      specified file name e.g: pi-movie.mov
        -d, --decrypt   specified key to decrypt and restrive file with filename called

        usage

        pifs -ef filename (e.g: filename = movie.mov) upload movie.mov to p2p nodes
        pifs -df filename (e.g: filename = movie.mov) download movie.mov from p2p 
          """)
def run():
    if(ecfile!="Empty"):
        ipfsUpload(ecfile)
    elif(defile!="Empty"):
        ipfsDownload(defile)


from distutils.core import setup
setup(
  name = 'pifs',         
  packages = ['pifs'],   
  version = '2.0.2',      
  license='MIT',       
  description = 'project use to encrypt and decrypt and upload to ipfs',
  author = 'Pionium',                
  author_email = 'pi@koompi.com',      
  url = 'https://github.com/koompi/pifs',   
  download_url = 'https://github.com/koompi/pifs/archive/master.zip',
  entry_points = {
        "console_scripts": ['pifs = pifs.updown:run']
        },
  install_requires=[      
          'ipfsapi',
          'cryptography',
      ],
  classifiers=[      
    'Intended Audience :: Developers',      
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   
    'Programming Language :: Python :: 3',      
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
  ],
)


# /usr/bin/env python
import ipfshttpclient

def ipfsFileAdd(filename):
    api = ipfshttpclient.connect('/ip4/127.0.0.1/tcp/5001/http') 
    ipfsLoadedFile = api.add(filename)
    ipfsHash = (ipfsLoadedFile['Hash'])
    return ipfsHash

def ipfsFileget(hash):
    api = ipfshttpclient.connect('/ip4/127.0.0.1/tcp/5001/http')
    api.get(hash)